"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bip39 = require("bip39");
const cbor = require("cbor");
const utils_1 = require("./utils");
const js_chain_libs_node_1 = require("js-chain-libs-node");
const ChainCode_1 = require("./ChainCode");
function tweakBits(data) {
    data[0] &= 248;
    data[31] &= 127;
    data[31] |= 64;
    return data;
}
function hashRepeatedly(key, i) {
    const [iL, iR] = utils_1.split(32, utils_1.hmacSha512(key, 'Root Seed Chain '.concat(String(i))));
    const prv = tweakBits(utils_1.sha512(iL));
    if (prv[31] & 32) {
        return hashRepeatedly(key, i + 1);
    }
    return Buffer.concat([prv, iR]);
}
function generateMasterKey(mnemonic) {
    const ent = Buffer.from(bip39.mnemonicToEntropy(mnemonic.join(' ')), 'hex');
    const seed = cbor.encode(utils_1.blake2b256(cbor.encode(ent)));
    const bytes = hashRepeatedly(seed, 1);
    return [
        js_chain_libs_node_1.PrivateKey.from_extended_bytes(bytes.slice(0, 64)),
        ChainCode_1.ChainCode.from_bytes(bytes.slice(64)),
    ];
}
exports.generateMasterKey = generateMasterKey;
//# sourceMappingURL=Byron.js.map